==> apache-druid-0.22.0-src.tar.gz: apache-druid-0.22.0-src/core/src/main/java/org/apache/druid/data/input/impl/TimeAndDimsParseSpec.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.data.input.impl;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.apache.druid.java.util.common.parsers.Parser;

import java.util.List;
import java.util.Map;

/**
 */
public class TimeAndDimsParseSpec extends ParseSpec
{
  @JsonCreator
  public TimeAndDimsParseSpec(
      @JsonProperty("timestampSpec") TimestampSpec timestampSpec,
      @JsonProperty("dimensionsSpec") DimensionsSpec dimensionsSpec
  )
  {
    super(
        timestampSpec != null ? timestampSpec : new TimestampSpec(null, null, null),
        dimensionsSpec != null ? dimensionsSpec : new DimensionsSpec(null, null, null)
    );
  }

  @Override
  public Parser<String, Object> makeParser()
  {
    return new Parser<String, Object>()
    {
      @Override
      public Map<String, Object> parseToMap(String input)
      {
        throw new UnsupportedOperationException("not supported");
      }

      @Override
      public void setFieldNames(Iterable<String> fieldNames)
      {
        throw new UnsupportedOperationException("not supported");
      }

      @Override
      public List<String> getFieldNames()
      {
        throw new UnsupportedOperationException("not supported");
      }
    };
  }

  @Override
  public ParseSpec withTimestampSpec(TimestampSpec spec)
  {
    return new TimeAndDimsParseSpec(spec, getDimensionsSpec());
  }

  @Override
  public ParseSpec withDimensionsSpec(DimensionsSpec spec)
  {
    return new TimeAndDimsParseSpec(getTimestampSpec(), spec);
  }
}

==> apache-druid-25.0.0-src.tar.gz: apache-druid-25.0.0-src/core/src/main/java/org/apache/druid/data/input/impl/TimeAndDimsParseSpec.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.druid.data.input.impl;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import org.apache.druid.java.util.common.parsers.Parser;

import java.util.List;
import java.util.Map;

/**
 */
public class TimeAndDimsParseSpec extends ParseSpec
{
  @JsonCreator
  public TimeAndDimsParseSpec(
      @JsonProperty("timestampSpec") TimestampSpec timestampSpec,
      @JsonProperty("dimensionsSpec") DimensionsSpec dimensionsSpec
  )
  {
    super(
        timestampSpec != null ? timestampSpec : new TimestampSpec(null, null, null),
        dimensionsSpec != null ? dimensionsSpec : DimensionsSpec.EMPTY
    );
  }

  @Override
  public Parser<String, Object> makeParser()
  {
    return new Parser<String, Object>()
    {
      @Override
      public Map<String, Object> parseToMap(String input)
      {
        throw new UnsupportedOperationException("not supported");
      }

      @Override
      public void setFieldNames(Iterable<String> fieldNames)
      {
        throw new UnsupportedOperationException("not supported");
      }

      @Override
      public List<String> getFieldNames()
      {
        throw new UnsupportedOperationException("not supported");
      }
    };
  }

  @Override
  public ParseSpec withTimestampSpec(TimestampSpec spec)
  {
    return new TimeAndDimsParseSpec(spec, getDimensionsSpec());
  }

  @Override
  public ParseSpec withDimensionsSpec(DimensionsSpec spec)
  {
    return new TimeAndDimsParseSpec(getTimestampSpec(), spec);
  }
}
